@@ -1,6 +1,6 @@
 #
 # ElementTree
-# $Id: ElementTree.py 65372 2008-08-01 19:11:22Z georg.brandl $
+# $Id$
 #
 # light-weight XML support for Python 2.2 and later.
 #
@@ -79,6 +79,10 @@
 # --------------------------------------------------------------------
 
 from __future__ import generators
+from __future__ import absolute_import
+
+from six import string_types
+
 
 __all__ = [
     # public symbols
@@ -144,7 +148,7 @@ class _SimpleElementPath(object):
         return result
 
 try:
-    import ElementPath
+    from . import ElementPath
 except ImportError:
     # FIXME: issue warning in this case?
     ElementPath = _SimpleElementPath()
@@ -242,7 +246,7 @@ class Element(object):
     def __len__(self):
         return len(self._children)
 
-    def __nonzero__(self):
+    def __bool__(self):
         import warnings
         warnings.warn(
             "The behavior of this method will change in future versions. "
@@ -250,6 +254,7 @@ class Element(object):
             FutureWarning
             )
         return len(self._children) != 0 # emulate old behaviour
+    __nonzero__ = __bool__  # for python2 compatibility
 
     ##
     # Returns the given subelement.
@@ -827,7 +832,7 @@ def _namespaces(elem, encoding, default_namespace=None):
         tag = elem.tag
         if isinstance(tag, QName) and tag.text not in qnames:
             add_qname(tag.text)
-        elif isinstance(tag, basestring):
+        elif isinstance(tag, string_types):
             if tag not in qnames:
                 add_qname(tag)
         elif tag is not None and tag is not Comment and tag is not PI:
@@ -862,7 +867,7 @@ def _serialize_xml(write, elem, encoding, qnames, namespaces):
             write("<" + tag)
             items = elem.items()
             if items or namespaces:
-                items.sort() # lexical order
+                items = sorted(items) # lexical order
                 for k, v in items:
                     if isinstance(k, QName):
                         k = k.text
@@ -873,7 +878,7 @@ def _serialize_xml(write, elem, encoding, qnames, namespaces):
                     write(" %s=\"%s\"" % (qnames[k], v))
                 if namespaces:
                     items = namespaces.items()
-                    items.sort(key=lambda x: x[1]) # sort on prefix
+                    items = sorted(items, key=lambda x: x[1]) # sort on prefix
                     for v, k in items:
                         if k:
                             k = ":" + k
@@ -919,7 +924,7 @@ def _serialize_html(write, elem, encoding, qnames, namespaces):
             write("<" + tag)
             items = elem.items()
             if items or namespaces:
-                items.sort() # lexical order
+                items = sorted(items) # lexical order
                 for k, v in items:
                     if isinstance(k, QName):
                         k = k.text
@@ -931,7 +936,7 @@ def _serialize_html(write, elem, encoding, qnames, namespaces):
                     write(" %s=\"%s\"" % (qnames[k], v))
                 if namespaces:
                     items = namespaces.items()
-                    items.sort(key=lambda x: x[1]) # sort on prefix
+                    items = sorted(items, key=lambda x: x[1]) # sort on prefix
                     for v, k in items:
                         if k:
                             k = ":" + k
@@ -1183,7 +1188,7 @@ class _IterParseIterator(object):
                     append((event, None))
                 parser.EndNamespaceDeclHandler = handler
 
-    def next(self):
+    def __next__(self):
         while 1:
             try:
                 item = self._events[self._index]
@@ -1204,6 +1209,8 @@ class _IterParseIterator(object):
                 self._index = self._index + 1
                 return item
 
+    next = __next__  # Python 2 compatibility
+
     def __iter__(self):
         return self
 
@@ -1425,12 +1432,16 @@ class XMLParser(object):
         err.position = value.lineno, value.offset
         raise err
 
-    def _fixtext(self, text):
-        # convert text string to ascii, if possible
-        try:
-            return text.encode("ascii")
-        except UnicodeError:
+    if sys.version_info >= (3, 0):
+        def _fixtext(self, text):
             return text
+    else:
+        def _fixtext(self, text):
+            # convert text string to ascii, if possible
+            try:
+                return text.encode("ascii")
+            except UnicodeError:
+                return text
 
     def _fixname(self, key):
         # expand qname, and convert name string to ascii, if possible
@@ -1520,7 +1531,7 @@ class XMLParser(object):
     def feed(self, data):
         try:
             self._parser.Parse(data, 0)
-        except self._error, v:
+        except self._error as v:
             self._raiseerror(v)
 
     ##
@@ -1532,7 +1543,7 @@ class XMLParser(object):
     def close(self):
         try:
             self._parser.Parse("", 1) # end of data
-        except self._error, v:
+        except self._error as v:
             self._raiseerror(v)
         tree = self.target.close()
         del self.target, self._parser # get rid of circular references
